# Step 1 : TODO Laponi : 

- Pull Request an example of a Profile.json in this repository 
- Pull Request an example of a Job.json in this repository
- Give an example of a POST request to upload a job to Laponi : payload + endpoint
- Give an example of a POST request to upload a profile to HrFlow.ai : payload + endpoint
- Give an example of a PUT/PATCH/POST request to edit a job from Laponi : payload + endpoint
- Give an example of a PUT/PATCH/POST request to cancel a job from Laponi : payload + endpoint 

# Step 2 : TODO HrFlow.ai :
- Implement workflow push_job_from_hrflow_into_laponi.py
- Implement workflow push_profile_from_laponi_into_hrflow.py
- Implement workflow edit_job_from_laponi_into_hrflow.py
- Implement workflow cancel_job_from_laponi_into_hrflow.py

